diff SDL_sound.h @ 149:1df5c106504e

Decoders can now list multiple file extensions.
author Ryan C. Gordon <icculus@icculus.org>
date Thu, 01 Nov 2001 19:13:17 +0000
parents ac49f81e42d6
children e91fb8d5bd62
line wrap: on
line diff
--- a/SDL_sound.h	Thu Nov 01 19:12:36 2001 +0000
+++ b/SDL_sound.h	Thu Nov 01 19:13:17 2001 +0000
@@ -112,10 +112,10 @@
  */
 typedef struct __SOUND_DECODERINFO__
 {
-    const char *extension;      /* standard file extension. "MP3", "WAV"... */
-    const char *description;    /* Human readable description of decoder.   */
-    const char *author;         /* "Name Of Author <email@emailhost.dom>"   */
-    const char *url;            /* URL specific to this decoder.            */
+    const char **extensions;    /* File extensions, list ends with NULL.  */
+    const char *description;    /* Human readable description of decoder. */
+    const char *author;         /* "Name Of Author <email@emailhost.dom>" */
+    const char *url;            /* URL specific to this decoder.          */
 } Sound_DecoderInfo;